Module silk

Module silk 

Re-exports

pub use resampler::SilkResampler;
pub use resampler::SilkResamplerDown1_3;
pub use resampler::SilkResamplerDown1_6;
pub use control_fixed::*;
pub use dec_api::*;
pub use decode_core::*;
pub use decode_frame::*;
pub use decode_indices::*;
pub use decode_parameters::*;
pub use decode_pulses::*;
pub use decoder_structs::*;
pub use define::*;
pub use encode_indices::*;
pub use encode_pulses::*;
pub use gain_quant::*;
pub use init_decoder::*;
pub use lin2log::*;
pub use log2lin::*;
pub use lpc_analysis::*;
pub use lpc_fit::*;
pub use nlsf::*;
pub use nlsf_decode::*;
pub use nlsf_del_dec_quant::*;
pub use nlsf_encode::*;
pub use nlsf_unpack::*;
pub use noise_shape_analysis::*;
pub use nsq::*;
pub use nsq_del_dec::*;
pub use pitch_analysis::*;
pub use shell_coder::*;
pub use sigm::*;
pub use sigproc_fix::*;
pub use sort::*;
pub use structs::*;
pub use tables::*;
pub use tables_nlsf::*;
pub use tuning_parameters::*;
pub use vq_wmat_ec::*;
pub use enc_api::*;

Modules

ana_filt_bank_1
biquad_alt
cng
SILK comfort-noise generation — port of silk/CNG.c.
control_codec
control_fixed
control_snr
dec_api
decode_core
decode_frame
decode_indices
decode_parameters
decode_pulses
decoder_structs
define
enc_api
encode_indices
encode_pulses
flp
Floating-point SILK analysis — a faithful port of libopus silk/float/.
gain_quant
hp_variable_cutoff
init_decoder
init_encoder
interpolate
lin2log
log2lin
lp_variable_cutoff
lpc_analysis
lpc_fit
ltp_analysis
macros
nlsf
nlsf_decode
nlsf_del_dec_quant
nlsf_encode
nlsf_unpack
noise_shape_analysis
nsq
nsq_del_dec
pitch_analysis
plc
Port of libopus silk/PLC.c — SILK packet-loss concealment. When a frame is lost the decoder extrapolates it from the previous frame’s LPC + LTP state plus attenuated random excitation (silk_PLC_conceal); on a good frame it refreshes the concealment state (silk_PLC_update); silk_PLC_glue_frames energy-matches the first good frame after a loss.
resampler
shell_coder
sigm
sigproc_fix
sort
structs
tables
tables_nlsf
tuning_parameters
vad
vq_wmat_ec

Type Aliases

SilkFloat