Re-exports
pub use resampler::SilkResampler;pub use resampler::SilkResamplerDown1_3;pub use resampler::SilkResamplerDown1_6;pub use control_fixed::*;pub use dec_api::*;pub use decode_core::*;pub use decode_frame::*;pub use decode_indices::*;pub use decode_parameters::*;pub use decode_pulses::*;pub use decoder_structs::*;pub use define::*;pub use encode_indices::*;pub use encode_pulses::*;pub use gain_quant::*;pub use init_decoder::*;pub use lin2log::*;pub use log2lin::*;pub use lpc_analysis::*;pub use lpc_fit::*;pub use nlsf::*;pub use nlsf_decode::*;pub use nlsf_del_dec_quant::*;pub use nlsf_encode::*;pub use nlsf_unpack::*;pub use noise_shape_analysis::*;pub use nsq::*;pub use nsq_del_dec::*;pub use pitch_analysis::*;pub use shell_coder::*;pub use sigm::*;pub use sigproc_fix::*;pub use sort::*;pub use structs::*;pub use tables::*;pub use tables_nlsf::*;pub use tuning_parameters::*;pub use vq_wmat_ec::*;pub use enc_api::*;
Modules
- ana_
filt_ bank_ 1 - biquad_
alt - cng
- SILK comfort-noise generation — port of
silk/CNG.c. - control_
codec - control_
fixed - control_
snr - dec_api
- decode_
core - decode_
frame - decode_
indices - decode_
parameters - decode_
pulses - decoder_
structs - define
- enc_api
- encode_
indices - encode_
pulses - flp
- Floating-point SILK analysis — a faithful port of libopus
silk/float/. - gain_
quant - hp_
variable_ cutoff - init_
decoder - init_
encoder - interpolate
- lin2log
- log2lin
- lp_
variable_ cutoff - lpc_
analysis - lpc_fit
- ltp_
analysis - macros
- nlsf
- nlsf_
decode - nlsf_
del_ dec_ quant - nlsf_
encode - nlsf_
unpack - noise_
shape_ analysis - nsq
- nsq_
del_ dec - pitch_
analysis - plc
- Port of libopus
silk/PLC.c— SILK packet-loss concealment. When a frame is lost the decoder extrapolates it from the previous frame’s LPC + LTP state plus attenuated random excitation (silk_PLC_conceal); on a good frame it refreshes the concealment state (silk_PLC_update); silk_PLC_glue_frames energy-matches the first good frame after a loss. - resampler
- shell_
coder - sigm
- sigproc_
fix - sort
- structs
- tables
- tables_
nlsf - tuning_
parameters - vad
- vq_
wmat_ ec